@@ -1,4 +1,4 @@
-__version__ = '1.1.4'
+__version__ = '1.1.5'
 
 import requests
 import json
@@ -68,6 +68,7 @@ class StreamBot:
             'Accept': 'text/event-stream',
             'Authorization': 'Bearer ' + self.api_key
         }
+        result = None
         try:
             # Fire off conversation message array to OpenAI  
             response = requests.post(self.openai_url, stream=True, headers=reqHeaders, json=reqBody)
@@ -75,15 +76,16 @@ class StreamBot:
             client = sseclient.SSEClient(response)
             # Array to capture the tokens since `response` will no longer be consumable
             response_text = []
-            print(self.bot_name + ": ")
             for event in client.events():
                 try:
-                    if self.verbosity >= 3:
-                      print(f"Event Data: {json.loads(event.data)}")
                     # Wrapped in try because json.loads fails due to `choices` not being present in last event
                     data = json.loads(event.data)['choices'][0]
+                    if self.verbosity >= 3:
+                      print(data)
                     # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
                     # Also check for ['finish_reason'] to break on last message
+                    if 'delta' in data and 'role' in data['delta']:
+                        print(self.bot_name + ": ")
                     if 'delta' in data and 'content' in data['delta'] and data['finish_reason'] != 'stop':
                         response_text.append(data['delta']['content'])
                         print(data['delta']['content'], end="", flush=True)
@@ -96,9 +98,10 @@ class StreamBot:
               print(f"Requests Error: {e}")
             pass
         
-        result = "".join(response_text)
+        if (response_text):
+          result = "".join(response_text)
       
-        self.add_message(result, role="assistant")
+          self.add_message(result, role="assistant")
         
         return result
 
@@ -122,6 +125,8 @@ class StreamBot:
                   data = json.loads(event.data)['choices'][0]
                   # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
                   # Also check for ['finish_reason'] to break on last message
+                  if 'delta' in data and 'role' in data['delta']:
+                      yield '[START_OF_STREAM]' #Helper string to know when to render new chat content
                   if 'delta' in data and 'content' in data['delta'] and data['finish_reason'] != 'stop':
                       yield data['delta']['content']
               except json.decoder.JSONDecodeError:
